@@ -6,7 +6,7 @@ use warnings;
 use lib qw|lib/ t/lib/ t/lib/RabbitMQ/ t/brokers/|;
 
 use Moose;
-with 'RabbitMQ::TestWorker', 'FailsOnceWillRetryWorker' => { -excludes => [ 'configuration', 'retries' ], };
+with 'RabbitMQ::TestWorker', 'FailsOnceWillRetryWorker' => { -excludes => [ 'configuration', 'lazy_queue', 'retries' ], };
 
 sub retries()
 {
